@@ -48,10 +48,10 @@ from apprise import NotifyImageSize
 from apprise import __version__
 from apprise import URLBase
 from apprise import PrivacyMode
-from apprise.AppriseLocale import LazyTranslation
-from apprise.AppriseLocale import gettext_lazy as _
+from apprise.locale import LazyTranslation
+from apprise.locale import gettext_lazy as _
 
-from apprise.NotificationManager import NotificationManager
+from apprise.manager_plugins import NotificationManager
 from apprise.utils import parse_list
 from helpers import OuterEventLoop
 import inspect
@@ -109,7 +109,7 @@ def apprise_test(do_notify):
 
     # We can load our servers up front as well
     servers = [
-        'faast://abcdefghijklmnop-abcdefg',
+        'json://myhost',
         'kodi://kodi.server.local',
     ]
 
