@@ -33,7 +33,7 @@ from unittest import mock
 import ctypes
 import pytest
 
-from apprise import AppriseLocale
+from apprise import locale
 from apprise.utils import environ
 from importlib import reload
 
@@ -46,7 +46,7 @@ def test_apprise_trans():
     """
     API: Test apprise locale object
     """
-    lazytrans = AppriseLocale.LazyTranslation('Token')
+    lazytrans = locale.LazyTranslation('Token')
     assert str(lazytrans) == 'Token'
 
 
@@ -57,17 +57,17 @@ def test_apprise_trans_gettext_init():
     API: Handle gettext
     """
     # Toggle
-    AppriseLocale.GETTEXT_LOADED = False
+    locale.GETTEXT_LOADED = False
 
     # Objects can still be created
-    al = AppriseLocale.AppriseLocale()
+    al = locale.AppriseLocale()
 
     with al.lang_at('en') as _:
         # functions still behave as normal
         assert _ is None
 
     # Restore the object
-    AppriseLocale.GETTEXT_LOADED = True
+    locale.GETTEXT_LOADED = True
 
 
 @pytest.mark.skipif(
@@ -87,14 +87,14 @@ def test_apprise_trans_gettext_translations(
     mock_gettext_trans.side_effect = FileNotFoundError()
 
     # This throws internally but we handle it gracefully
-    al = AppriseLocale.AppriseLocale()
+    al = locale.AppriseLocale()
 
     with al.lang_at('en'):
         # functions still behave as normal
         pass
 
     # This throws internally but we handle it gracefully
-    AppriseLocale.AppriseLocale(language="fr")
+    locale.AppriseLocale(language="fr")
 
 
 @pytest.mark.skipif(
@@ -112,7 +112,7 @@ def test_apprise_trans_gettext_lang_at(mock_getlocale):
     mock_getlocale.return_value = ('en_CA', 'UTF-8')
 
     # This throws internally but we handle it gracefully
-    al = AppriseLocale.AppriseLocale()
+    al = locale.AppriseLocale()
 
     # Edge Cases
     assert al.add('en', set_default=False) is True
@@ -123,7 +123,7 @@ def test_apprise_trans_gettext_lang_at(mock_getlocale):
         pass
 
     # This throws internally but we handle it gracefully
-    AppriseLocale.AppriseLocale(language="fr")
+    locale.AppriseLocale(language="fr")
 
     with al.lang_at('en') as _:
         # functions still behave as normal
@@ -141,17 +141,17 @@ def test_apprise_trans_gettext_lang_at(mock_getlocale):
     # not have. This is only done to test edge cases when for whatever
     # reason the person who set up apprise does not have the languages
     # installed.
-    fallback = AppriseLocale.AppriseLocale._default_language
+    fallback = locale.AppriseLocale._default_language
     mock_getlocale.return_value = None
 
     with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', 'LANG'):
         # Our default language
-        AppriseLocale.AppriseLocale._default_language = 'zz'
+        locale.AppriseLocale._default_language = 'zz'
 
         # We will detect the zz since there were no environment variables to
         # help us otherwise
-        assert AppriseLocale.AppriseLocale.detect_language() is None
-        al = AppriseLocale.AppriseLocale()
+        assert locale.AppriseLocale.detect_language() is None
+        al = locale.AppriseLocale()
 
         # No Language could be set becuause no locale directory exists for this
         assert al.lang is None
@@ -177,12 +177,12 @@ def test_apprise_trans_gettext_lang_at(mock_getlocale):
 
     with environ('LANGUAGE', 'LC_CTYPE', LC_ALL='C.UTF-8', LANG="en_CA"):
         # the UTF-8 entry is skipped over
-        AppriseLocale.AppriseLocale._default_language = 'fr'
+        locale.AppriseLocale._default_language = 'fr'
 
         # We will detect the english language (found in the LANG= environment
         # variable which over-rides the _default
-        assert AppriseLocale.AppriseLocale.detect_language() == "en"
-        al = AppriseLocale.AppriseLocale()
+        assert locale.AppriseLocale.detect_language() == "en"
+        al = locale.AppriseLocale()
         assert al.lang == "en"
         assert al.gettext('test') == 'test'
 
@@ -194,7 +194,7 @@ def test_apprise_trans_gettext_lang_at(mock_getlocale):
         assert al.gettext('test') == 'test'
 
         assert al.add('zy', set_default=False) is False
-    AppriseLocale.AppriseLocale._default_language = fallback
+    locale.AppriseLocale._default_language = fallback
 
 
 @pytest.mark.skipif(
@@ -206,17 +206,17 @@ def test_apprise_trans_add():
     """
 
     # This throws internally but we handle it gracefully
-    al = AppriseLocale.AppriseLocale()
+    al = locale.AppriseLocale()
     with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', 'LANG'):
         # English is the default/fallback type
         assert al.add('en') is True
 
-    al = AppriseLocale.AppriseLocale()
+    al = locale.AppriseLocale()
     with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', LANG='C.UTF-8'):
         # Test English Environment
         assert al.add('en') is True
 
-    al = AppriseLocale.AppriseLocale()
+    al = locale.AppriseLocale()
     with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', LANG='en_CA.UTF-8'):
         # Test English Environment
         assert al.add('en') is True
@@ -251,29 +251,29 @@ def test_apprise_trans_windows_users_win(mock_getlocale):
 
         with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', 'LANG'):
             # Our default language
-            AppriseLocale.AppriseLocale._default_language = 'zz'
+            locale.AppriseLocale._default_language = 'zz'
 
             # We will pick up the windll module and detect english
-            assert AppriseLocale.AppriseLocale.detect_language() == 'en'
+            assert locale.AppriseLocale.detect_language() == 'en'
 
         # The below accesses the windows fallback code
         with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', LANG="es_AR"):
             # Environment Variable Trumps
-            assert AppriseLocale.AppriseLocale.detect_language() == 'es'
+            assert locale.AppriseLocale.detect_language() == 'es'
 
         # No environment variable, then the Windows environment is used
         with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', 'LANG'):
             # Windows Environment
-            assert AppriseLocale.AppriseLocale.detect_language() == 'en'
+            assert locale.AppriseLocale.detect_language() == 'en'
 
-        assert AppriseLocale.AppriseLocale\
+        assert locale.AppriseLocale\
             .detect_language(detect_fallback=False) is None
 
         # 0 = IndexError
         ui_lang.return_value = 0
         with environ('LANGUAGE', 'LANG', 'LC_ALL', 'LC_CTYPE'):
             # We fall back to posix locale
-            assert AppriseLocale.AppriseLocale.detect_language() == 'fr'
+            assert locale.AppriseLocale.detect_language() == 'fr'
 
 
 @pytest.mark.skipif(
@@ -299,29 +299,29 @@ def test_apprise_trans_windows_users_nux(mock_getlocale):
 
     with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', 'LANG'):
         # Our default language
-        AppriseLocale.AppriseLocale._default_language = 'zz'
+        locale.AppriseLocale._default_language = 'zz'
 
         # We will pick up the windll module and detect english
-        assert AppriseLocale.AppriseLocale.detect_language() == 'en'
+        assert locale.AppriseLocale.detect_language() == 'en'
 
     # The below accesses the windows fallback code
     with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', LANG="es_AR"):
         # Environment Variable Trumps
-        assert AppriseLocale.AppriseLocale.detect_language() == 'es'
+        assert locale.AppriseLocale.detect_language() == 'es'
 
     # No environment variable, then the Windows environment is used
     with environ('LANGUAGE', 'LC_ALL', 'LC_CTYPE', 'LANG'):
         # Windows Environment
-        assert AppriseLocale.AppriseLocale.detect_language() == 'en'
+        assert locale.AppriseLocale.detect_language() == 'en'
 
-    assert AppriseLocale.AppriseLocale\
+    assert locale.AppriseLocale\
         .detect_language(detect_fallback=False) is None
 
     # 0 = IndexError
     windll.kernel32.GetUserDefaultUILanguage.return_value = 0
     with environ('LANGUAGE', 'LANG', 'LC_ALL', 'LC_CTYPE'):
         # We fall back to posix locale
-        assert AppriseLocale.AppriseLocale.detect_language() == 'fr'
+        assert locale.AppriseLocale.detect_language() == 'fr'
 
     delattr(ctypes, 'windll')
 
@@ -341,11 +341,11 @@ def test_detect_language_using_env(mock_getlocale):
     with environ('LANG', 'LANGUAGE', 'LC_ALL', 'LC_CTYPE'):
         # Language can now be detected in this case
         assert isinstance(
-            AppriseLocale.AppriseLocale.detect_language(), str)
+            locale.AppriseLocale.detect_language(), str)
 
     # Detect French language.
     with environ('LANGUAGE', 'LC_ALL', LC_CTYPE="garbage", LANG="fr_CA"):
-        assert AppriseLocale.AppriseLocale.detect_language() == 'fr'
+        assert locale.AppriseLocale.detect_language() == 'fr'
 
     # The following unsets all environment variables and sets LC_CTYPE
     # This was causing Python 2.7 to internally parse UTF-8 as an invalid
@@ -353,24 +353,24 @@ def test_detect_language_using_env(mock_getlocale):
     # dropped, but just to ensure this issue does not come back, we keep
     # this test:
     with environ(*list(os.environ.keys()), LC_CTYPE="UTF-8"):
-        assert isinstance(AppriseLocale.AppriseLocale.detect_language(), str)
+        assert isinstance(locale.AppriseLocale.detect_language(), str)
 
     # Test with absolutely no environment variables what-so-ever
     with environ(*list(os.environ.keys())):
-        assert isinstance(AppriseLocale.AppriseLocale.detect_language(), str)
+        assert isinstance(locale.AppriseLocale.detect_language(), str)
 
     # Handle case where getlocale() can't be detected
     mock_getlocale.return_value = None
     with environ('LC_ALL', 'LC_CTYPE', 'LANG', 'LANGUAGE'):
-        assert AppriseLocale.AppriseLocale.detect_language() is None
+        assert locale.AppriseLocale.detect_language() is None
 
     mock_getlocale.return_value = (None, None)
     with environ('LC_ALL', 'LC_CTYPE', 'LANG', 'LANGUAGE'):
-        assert AppriseLocale.AppriseLocale.detect_language() is None
+        assert locale.AppriseLocale.detect_language() is None
 
     # if detect_language and windows env fail us, then we don't
     # set up a default language on first load
-    AppriseLocale.AppriseLocale()
+    locale.AppriseLocale()
 
 
 @pytest.mark.skipif(
@@ -393,14 +393,14 @@ def test_apprise_trans_gettext_missing(tmpdir):
     sys.path.insert(0, str(gettext_dir))
 
     # reload our module (forcing the import error when it tries to load gettext
-    reload(sys.modules['apprise.AppriseLocale'])
-    from apprise import AppriseLocale
-    assert AppriseLocale.GETTEXT_LOADED is False
+    reload(sys.modules['apprise.locale'])
+    from apprise import locale
+    assert locale.GETTEXT_LOADED is False
 
     # Now roll our changes back
     sys.path.pop(0)
 
     # Reload again (reverting back)
-    reload(sys.modules['apprise.AppriseLocale'])
-    from apprise import AppriseLocale
-    assert AppriseLocale.GETTEXT_LOADED is True
+    reload(sys.modules['apprise.locale'])
+    from apprise import locale
+    assert locale.GETTEXT_LOADED is True
