@@ -33,7 +33,7 @@ from inspect import cleandoc
 from urllib.parse import unquote
 
 from apprise import utils
-from apprise.NotificationManager import NotificationManager
+from apprise.manager_plugins import NotificationManager
 
 # Disable logging for a cleaner testing output
 import logging
@@ -50,7 +50,7 @@ def test_parse_qsd():
     "utils: parse_qsd() testing """
 
     result = utils.parse_qsd('a=1&b=&c&d=abcd')
-    assert isinstance(result, dict) is True
+    assert isinstance(result, dict)
     assert len(result) == 4
     assert 'qsd' in result
     assert 'qsd+' in result
@@ -719,6 +719,38 @@ def test_parse_url_general():
     assert result['qsd+'] == {}
     assert result['qsd:'] == {}
 
+    # Sanitizing
+    result = utils.parse_url(
+        'hTTp://hostname/?+KeY=ValueA&-kEy=ValueB&KEY=Value%20+C&:cOlON=YeS',
+        sanitize=False)
+
+    assert len(result['qsd-']) == 1
+    assert len(result['qsd+']) == 1
+    assert len(result['qsd']) == 4
+    assert len(result['qsd:']) == 1
+
+    assert result['schema'] == 'http'
+    assert result['host'] == 'hostname'
+    assert result['port'] is None
+    assert result['user'] is None
+    assert result['password'] is None
+    assert result['fullpath'] == '/'
+    assert result['path'] == '/'
+    assert result['query'] is None
+    assert result['url'] == 'http://hostname/'
+    assert '+KeY' in result['qsd']
+    assert '-kEy' in result['qsd']
+    assert ':cOlON' in result['qsd']
+    assert result['qsd:']['cOlON'] == 'YeS'
+    assert 'key' not in result['qsd']
+    assert 'KeY' in result['qsd+']
+    assert result['qsd+']['KeY'] == 'ValueA'
+    assert 'kEy' in result['qsd-']
+    assert result['qsd-']['kEy'] == 'ValueB'
+    assert result['qsd']['KEY'] == 'Value +C'
+    assert result['qsd']['+KeY'] == result['qsd+']['KeY']
+    assert result['qsd']['-kEy'] == result['qsd-']['kEy']
+
 
 def test_parse_url_simple():
     "utils: parse_url() testing """
@@ -2607,39 +2639,39 @@ def test_apply_templating():
 
     result = utils.apply_template(
         template, **{'fname': 'Chris', 'whence': 'this morning'})
-    assert isinstance(result, str) is True
+    assert isinstance(result, str)
     assert result == "Hello Chris, How are you this morning?"
 
     # In this example 'whence' isn't provided, so it isn't swapped
     result = utils.apply_template(
         template, **{'fname': 'Chris'})
-    assert isinstance(result, str) is True
+    assert isinstance(result, str)
     assert result == "Hello Chris, How are you {{whence}}?"
 
     # white space won't cause any ill affects:
     template = "Hello {{ fname }}, How are you {{   whence}}?"
     result = utils.apply_template(
         template, **{'fname': 'Chris', 'whence': 'this morning'})
-    assert isinstance(result, str) is True
+    assert isinstance(result, str)
     assert result == "Hello Chris, How are you this morning?"
 
     # No arguments won't cause any problems
     template = "Hello {{fname}}, How are you {{whence}}?"
     result = utils.apply_template(template)
-    assert isinstance(result, str) is True
+    assert isinstance(result, str)
     assert result == template
 
     # Wrong elements are simply ignored
     result = utils.apply_template(
         template,
         **{'fname': 'l2g', 'whence': 'this evening', 'ignore': 'me'})
-    assert isinstance(result, str) is True
+    assert isinstance(result, str)
     assert result == "Hello l2g, How are you this evening?"
 
     # Empty template makes things easy
     result = utils.apply_template(
         "", **{'fname': 'l2g', 'whence': 'this evening'})
-    assert isinstance(result, str) is True
+    assert isinstance(result, str)
     assert result == ""
 
     # Regular expressions are safely escapped and act as normal
