@@ -34,10 +34,10 @@ import mimetypes
 from os.path import join
 from os.path import dirname
 from os.path import getsize
-from apprise.attachment.AttachHTTP import AttachHTTP
-from apprise import AppriseAttachment
-from apprise.NotificationManager import NotificationManager
-from apprise.plugins.NotifyBase import NotifyBase
+from apprise.attachment.http import AttachHTTP
+from apprise import Apprise, AppriseAttachment
+from apprise.manager_plugins import NotificationManager
+from apprise.plugins import NotifyBase
 from apprise.common import ContentLocation
 
 # Disable logging for a cleaner testing output
@@ -113,8 +113,9 @@ def test_attach_http_query_string_dictionary():
     assert re.search(r'[?&]_var=test', obj.url())
 
 
+@mock.patch('requests.post')
 @mock.patch('requests.get')
-def test_attach_http(mock_get):
+def test_attach_http(mock_get, mock_post):
     """
     API: AttachHTTP() object
 
@@ -189,7 +190,7 @@ def test_attach_http(mock_get):
 
     # Test custom url get parameters
     results = AttachHTTP.parse_url(
-        'http://user:pass@localhost/apprise.gif?dl=1&cache=300')
+        'http://user:pass@localhost/apprise.gif?DL=1&cache=300')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
     assert isinstance(attachment.url(), str) is True
@@ -199,12 +200,16 @@ def test_attach_http(mock_get):
     assert attachment
     assert mock_get.call_count == 1
     assert 'params' in mock_get.call_args_list[0][1]
-    assert 'dl' in mock_get.call_args_list[0][1]['params']
+    assert 'DL' in mock_get.call_args_list[0][1]['params']
 
     # Verify that arguments that are reserved for apprise are not
     # passed along
     assert 'cache' not in mock_get.call_args_list[0][1]['params']
 
+    with mock.patch('os.unlink', side_effect=OSError()):
+        # Test invalidation with exception thrown
+        attachment.invalidate()
+
     results = AttachHTTP.parse_url(
         'http://user:pass@localhost/apprise.gif?+key=value&cache=True')
     assert isinstance(results, dict)
@@ -422,3 +427,50 @@ def test_attach_http(mock_get):
 
     # Restore value
     AttachHTTP.max_file_size = max_file_size
+
+    # Multi Message Testing
+    mock_get.side_effect = None
+    mock_get.return_value = DummyResponse()
+
+    # Prepare our POST response (from notify call)
+    response = requests.Request()
+    response.status_code = requests.codes.ok
+    response.content = ""
+    mock_post.return_value = response
+
+    mock_get.reset_mock()
+    mock_post.reset_mock()
+    assert mock_get.call_count == 0
+
+    apobj = Apprise()
+    assert apobj.add('form://localhost')
+    assert apobj.add('json://localhost')
+    assert apobj.add('xml://localhost')
+    assert len(apobj) == 3
+    assert apobj.notify(
+        body='one attachment split 3 times',
+        attach="http://localhost/test.gif",
+    ) is True
+
+    # We posted 3 times
+    assert mock_post.call_count == 3
+    # We only fetched once and re-used the same fetch for all posts
+    assert mock_get.call_count == 1
+
+    mock_get.reset_mock()
+    mock_post.reset_mock()
+    apobj = Apprise()
+    for n in range(10):
+        assert apobj.add(f'json://localhost?:entry={n}&method=post')
+        assert apobj.add(f'form://localhost?:entry={n}&method=post')
+        assert apobj.add(f'xml://localhost?:entry={n}&method=post')
+
+    assert apobj.notify(
+        body='one attachment split 30 times',
+        attach="http://localhost/test.gif",
+    ) is True
+
+    # We posted 30 times
+    assert mock_post.call_count == 30
+    # We only fetched once and re-used the same fetch for all posts
+    assert mock_get.call_count == 1
