@@ -27,8 +27,8 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import pytest
-from apprise.AppriseAsset import AppriseAsset
-from apprise.config.ConfigBase import ConfigBase
+from apprise import AppriseAsset
+from apprise.config import ConfigBase
 from apprise import Apprise
 from apprise import ConfigFormat
 from inspect import cleandoc
@@ -37,7 +37,7 @@ import yaml
 # Disable logging for a cleaner testing output
 import logging
 
-from apprise.plugins.NotifyEmail import NotifyEmail
+from apprise.plugins.email import NotifyEmail
 
 logging.disable(logging.CRITICAL)
 
@@ -221,6 +221,32 @@ urls:
     assert len(result) == 1
 
 
+def test_config_base_discord_bug_report_01():
+    """
+    API: ConfigBase.config_parse user feedback
+
+    A Discord report that a tag was not correctly assigned to a URL when
+    presented in the following format
+       urls:
+         - json://myhost:
+           - tag: test
+             userid: test
+    """
+    result, config = ConfigBase.config_parse("""
+    urls:
+      - json://myhost:
+        - tag: test
+          userid: test
+    """, asset=AppriseAsset())
+
+    # We expect to parse 4 entries from the above
+    assert isinstance(result, list)
+    assert isinstance(config, list)
+    assert len(result) == 1
+    assert len(result[0].tags) == 1
+    assert 'test' in result[0].tags
+
+
 def test_config_base_config_parse_text():
     """
     API: ConfigBase.config_parse_text object
@@ -954,9 +980,9 @@ urls:
     assert asset.theme == AppriseAsset().theme
 
     # Empty string assignment
-    assert isinstance(asset.image_url_mask, str) is True
+    assert isinstance(asset.image_url_mask, str)
     assert asset.image_url_mask == ""
-    assert isinstance(asset.image_url_logo, str) is True
+    assert isinstance(asset.image_url_logo, str)
     assert asset.image_url_logo == ""
 
     # For on-lookers looking through this file; here is a perfectly formatted
