@@ -29,12 +29,13 @@
 from os.path import dirname
 from os.path import join
 from apprise.decorators import notify
+from apprise.decorators.base import CustomNotifyPlugin
 from apprise import Apprise
 from apprise import AppriseConfig
 from apprise import AppriseAsset
 from apprise import AppriseAttachment
 from apprise import common
-from apprise.NotificationManager import NotificationManager
+from apprise.manager_plugins import NotificationManager
 
 # Disable logging for a cleaner testing output
 import logging
@@ -61,6 +62,16 @@ def test_notify_simple_decoration():
     def my_inline_notify_wrapper(
             body, title, notify_type, attach, *args, **kwargs):
 
+        # Test our body (always present)
+        assert isinstance(body, str)
+
+        # Ensure content is of type utf-8
+        assert isinstance(body.encode('utf-8'), bytes)
+
+        if attach:
+            # attachment is always of type AppriseAttach
+            assert isinstance(attach, AppriseAttachment)
+
         # Populate our object we can use to validate
         verify_obj.update({
             'body': body,
@@ -119,6 +130,108 @@ def test_notify_simple_decoration():
     # Reset our verify object (so it can be populated again)
     verify_obj = {}
 
+    # Send unicode
+    assert aobj.notify("ツ".encode('utf-8')) is True
+    # Our content was populated after the notify() call
+    assert len(verify_obj) > 0
+    assert verify_obj['body'] == "ツ"  # content comes back as str (utf-8)
+    assert verify_obj['title'] == ''
+    assert verify_obj['notify_type'] == common.NotifyType.INFO
+    assert verify_obj['attach'] is None
+
+    # No format was defined
+    assert 'body_format' in verify_obj['kwargs']
+    assert verify_obj['kwargs']['body_format'] is None
+
+    # The meta argument allows us to further parse the URL parameters
+    # specified
+    assert isinstance(verify_obj['kwargs'], dict)
+    assert 'meta' in verify_obj['kwargs']
+    assert isinstance(verify_obj['kwargs']['meta'], dict)
+    assert len(verify_obj['kwargs']['meta']) == 4
+    assert 'tag' in verify_obj['kwargs']['meta']
+
+    assert 'asset' in verify_obj['kwargs']['meta']
+    assert isinstance(verify_obj['kwargs']['meta']['asset'], AppriseAsset)
+
+    assert verify_obj['kwargs']['meta']['schema'] == 'utiltest'
+    assert verify_obj['kwargs']['meta']['url'] == 'utiltest://'
+
+    # Reset our verify object (so it can be populated again)
+    verify_obj = {}
+
+    # Send utf-8 string
+    assert aobj.notify("ツ") is True
+
+    assert len(verify_obj) > 0
+    assert verify_obj['body'] == "ツ"  # content comes back as str (utf-8)
+    assert verify_obj['title'] == ''
+    assert verify_obj['notify_type'] == common.NotifyType.INFO
+    assert verify_obj['attach'] is None
+
+    # No format was defined
+    assert 'body_format' in verify_obj['kwargs']
+    assert verify_obj['kwargs']['body_format'] is None
+
+    # The meta argument allows us to further parse the URL parameters
+    # specified
+    assert isinstance(verify_obj['kwargs'], dict)
+    assert 'meta' in verify_obj['kwargs']
+    assert isinstance(verify_obj['kwargs']['meta'], dict)
+    assert len(verify_obj['kwargs']['meta']) == 4
+    assert 'tag' in verify_obj['kwargs']['meta']
+
+    assert 'asset' in verify_obj['kwargs']['meta']
+    assert isinstance(verify_obj['kwargs']['meta']['asset'], AppriseAsset)
+
+    assert verify_obj['kwargs']['meta']['schema'] == 'utiltest'
+    assert verify_obj['kwargs']['meta']['url'] == 'utiltest://'
+
+    # Some cases that will fail internal validation:
+    # - No Body
+    assert aobj.notify('') is False
+    # - Title only
+    assert aobj.notify('', title="hello world!") is False
+
+    # Reset our verify object (so it can be populated again)
+    verify_obj = {}
+
+    # No Body but has attachment (valid)
+    assert aobj.notify(
+        '',
+        attach=(
+            join(TEST_VAR_DIR, 'apprise-test.png'),
+        )) is True
+
+    # Our content was populated after the notify() call
+    assert len(verify_obj) > 0
+    assert verify_obj['body'] == ""
+    assert verify_obj['title'] == ""
+    assert verify_obj['notify_type'] == common.NotifyType.INFO
+    assert isinstance(verify_obj['attach'], AppriseAttachment)
+    assert len(verify_obj['attach']) == 1
+
+    # No format was defined
+    assert 'body_format' in verify_obj['kwargs']
+    assert verify_obj['kwargs']['body_format'] is None
+
+    # The meta argument allows us to further parse the URL parameters
+    # specified
+    assert isinstance(verify_obj['kwargs'], dict)
+    assert 'meta' in verify_obj['kwargs']
+    assert isinstance(verify_obj['kwargs']['meta'], dict)
+    assert len(verify_obj['kwargs']['meta']) == 4
+    assert 'tag' in verify_obj['kwargs']['meta']
+
+    assert 'asset' in verify_obj['kwargs']['meta']
+    assert isinstance(verify_obj['kwargs']['meta']['asset'], AppriseAsset)
+
+    assert verify_obj['kwargs']['meta']['schema'] == 'utiltest'
+    assert verify_obj['kwargs']['meta']['url'] == 'utiltest://'
+
+    # Reset our verify object (so it can be populated again)
+    verify_obj = {}
+
     # We'll do another test now
     assert aobj.notify(
         "Hello Another World", title="My Other Title",
@@ -333,6 +446,8 @@ def test_notify_multi_instance_decoration(tmpdir):
     def my_inline_notify_wrapper(
             body, title, notify_type, attach, meta, *args, **kwargs):
 
+        assert isinstance(body, str)
+
         # Track what is added
         verify_obj.append({
             'body': body,
@@ -351,7 +466,7 @@ def test_notify_multi_instance_decoration(tmpdir):
     t = tmpdir.mkdir("multi-test").join("apprise.yml")
     t.write("""urls:
     - multi://user1:pass@hostname
-    - multi://user2:pass2@hostname
+    - multi://user2:pass2@hostname?verify=no
     """)
 
     # Create ourselves a config object
@@ -372,7 +487,8 @@ def test_notify_multi_instance_decoration(tmpdir):
     # Nothing stored yet in our object
     assert len(verify_obj) == 0
 
-    assert aobj.notify("Hello World", title="My Title") is True
+    # Send utf-8 characters
+    assert aobj.notify("ツ".encode('utf-8'), title="My Title") is True
 
     assert len(verify_obj) == 2
 
@@ -383,7 +499,7 @@ def test_notify_multi_instance_decoration(tmpdir):
 
     # Our content was populated after the notify() call
     obj = verify_obj[0]
-    assert obj['body'] == "Hello World"
+    assert obj['body'] == "ツ"
     assert obj['title'] == "My Title"
     assert obj['notify_type'] == common.NotifyType.INFO
 
@@ -404,11 +520,12 @@ def test_notify_multi_instance_decoration(tmpdir):
     assert 'tag' in meta
     assert isinstance(meta['tag'], set)
 
-    assert len(meta) == 7
+    assert len(meta) == 8
     # We carry all of our default arguments from the @notify's initialization
     assert meta['schema'] == 'multi'
     assert meta['host'] == 'hostname'
     assert meta['user'] == 'user1'
+    assert meta['verify'] is True
     assert meta['password'] == 'pass'
 
     # Verify our URL is correct
@@ -420,7 +537,7 @@ def test_notify_multi_instance_decoration(tmpdir):
 
     # Our content was populated after the notify() call
     obj = verify_obj[1]
-    assert obj['body'] == "Hello World"
+    assert obj['body'] == "ツ"
     assert obj['title'] == "My Title"
     assert obj['notify_type'] == common.NotifyType.INFO
 
@@ -441,15 +558,24 @@ def test_notify_multi_instance_decoration(tmpdir):
     assert 'tag' in meta
     assert isinstance(meta['tag'], set)
 
-    assert len(meta) == 7
+    assert len(meta) == 9
     # We carry all of our default arguments from the @notify's initialization
     assert meta['schema'] == 'multi'
     assert meta['host'] == 'hostname'
     assert meta['user'] == 'user2'
     assert meta['password'] == 'pass2'
+    assert meta['verify'] is False
+    assert meta['qsd']['verify'] == 'no'
 
     # Verify our URL is correct
-    assert meta['url'] == 'multi://user2:pass2@hostname'
+    assert meta['url'] == 'multi://user2:pass2@hostname?verify=no'
 
     # Tidy
     N_MGR.remove('multi')
+
+
+def test_custom_notify_plugin_decoration():
+    """decorators: CustomNotifyPlugin testing
+    """
+
+    CustomNotifyPlugin()
