@@ -35,7 +35,7 @@ from apprise import Apprise
 from apprise import AppriseAttachment
 from apprise import NotifyType
 
-from apprise.plugins.NotifyJSON import NotifyJSON
+from apprise.plugins.custom_json import NotifyJSON
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -187,7 +187,7 @@ def test_plugin_custom_json_edge_cases(mock_get, mock_post):
     assert results['query'] == 'command'
     assert results['schema'] == 'json'
     assert results['url'] == 'json://localhost:8080/command'
-    assert isinstance(results['qsd:'], dict) is True
+    assert isinstance(results['qsd:'], dict)
     assert results['qsd:']['message'] == 'msg'
     # empty special mapping
     assert results['qsd:']['type'] == ''
@@ -321,7 +321,7 @@ def test_plugin_custom_form_for_synology(mock_post):
     assert results['query'] == 'entry.cgi'
     assert results['schema'] == 'jsons'
     assert results['url'] == 'jsons://localhost:8081/webapi/entry.cgi'
-    assert isinstance(results['qsd:'], dict) is True
+    assert isinstance(results['qsd:'], dict)
     # Header Entries
     assert results['qsd-']['api'] == 'SYNO.Chat.External'
     assert results['qsd-']['method'] == 'incoming'
