@@ -27,9 +27,11 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import logging
+import pytest
 import os
 import re
 from unittest import mock
+from inspect import cleandoc
 
 import smtplib
 from email.header import decode_header
@@ -37,9 +39,11 @@ from email.header import decode_header
 from apprise import NotifyType, NotifyBase
 from apprise import Apprise
 from apprise import AttachBase
+from apprise import AppriseAsset
+from apprise.config import ConfigBase
 from apprise import AppriseAttachment
-from apprise.plugins.NotifyEmail import NotifyEmail
-from apprise.plugins import NotifyEmail as NotifyEmailModule
+from apprise.plugins.email import NotifyEmail
+from apprise.plugins import email as NotifyEmailModule
 
 # Disable logging for a cleaner testing output
 logging.disable(logging.CRITICAL)
@@ -53,13 +57,13 @@ TEST_URLS = (
     # NotifyEmail
     ##################################
     ('mailto://', {
-        'instance': None,
+        'instance': TypeError,
     }),
     ('mailtos://', {
-        'instance': None,
+        'instance': TypeError,
     }),
     ('mailto://:@/', {
-        'instance': None
+        'instance': TypeError,
     }),
     # No Username
     ('mailtos://:pass@nuxref.com:567', {
@@ -342,14 +346,14 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
 
             if isinstance(obj, NotifyBase):
                 # We loaded okay; now lets make sure we can reverse this url
-                assert isinstance(obj.url(), str) is True
+                assert isinstance(obj.url(), str)
 
                 # Verify we can acquire a target count as an integer
                 assert isinstance(len(obj), int)
 
                 # Test url() with privacy=True
                 assert isinstance(
-                    obj.url(privacy=True), str) is True
+                    obj.url(privacy=True), str)
 
                 # Some Simple Invalid Instance Testing
                 assert instance.parse_url(None) is None
@@ -375,12 +379,10 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
                     assert False
 
                 # Verify there is no change from the old and the new
-                if len(obj) != len(obj_cmp):
-                    print('%d targets found in %s' % (
-                        len(obj), obj.url(privacy=True)))
-                    print('But %d targets found in %s' % (
-                        len(obj_cmp), obj_cmp.url(privacy=True)))
-                    raise AssertionError("Target miscount %d != %d")
+                assert len(obj) == len(obj_cmp), (
+                    '%d targets found in %s, But %d targets found in %s'
+                    % (len(obj), obj.url(privacy=True), len(obj_cmp),
+                       obj_cmp.url(privacy=True)))
 
             if self:
                 # Iterate over our expected entries inside of our object
@@ -438,9 +440,12 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
         except Exception as e:
             # Handle our exception
             if instance is None:
+                print('%s generated %s' % (url, str(e)))
                 raise
 
             if not isinstance(e, instance):
+                print('%s Exception (expected %s); got %s' % (
+                    url, str(instance), str(e)))
                 raise
 
 
@@ -704,7 +709,7 @@ def test_plugin_email_url_escaping():
     obj = NotifyEmail.parse_url(
         'mailto://user:{}@gmail.com?format=text'.format(passwd))
 
-    assert isinstance(obj, dict) is True
+    assert isinstance(obj, dict)
     assert 'password' in obj
 
     # Escaping doesn't happen at this stage because we want to leave this to
@@ -714,7 +719,7 @@ def test_plugin_email_url_escaping():
     obj = Apprise.instantiate(
         'mailto://user:{}@gmail.com?format=text'.format(passwd),
         suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     # The password is escaped only 'once'
     assert obj.password == ' %20'
@@ -732,7 +737,7 @@ def test_plugin_email_url_variations():
             user='apprise%40example21.ca',
             passwd='abcd123'),
         suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
@@ -755,7 +760,7 @@ def test_plugin_email_url_variations():
             user='apprise%40example21.ca',
             passwd='abcd123'),
         suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
@@ -777,7 +782,7 @@ def test_plugin_email_url_variations():
             user='apprise%40example21.ca',
             passwd='abcd123'),
         suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
@@ -807,7 +812,7 @@ def test_plugin_email_url_variations():
             user='apprise%40example21.ca',
             passwd='abcd123'),
         suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
@@ -841,7 +846,7 @@ def test_plugin_email_url_variations():
             that='to@example.jp',
             smtp_host='smtp.example.edu'),
         suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert obj.password == 'abcd123'
     assert obj.user == 'apprise@example21.ca'
@@ -863,7 +868,7 @@ def test_plugin_email_url_variations():
 
         obj = Apprise.instantiate(
             'mailto://user:pass@domain.com{}'.format(toaddr))
-        assert isinstance(obj, NotifyEmail) is True
+        assert isinstance(obj, NotifyEmail)
         assert obj.password == 'pass'
         assert obj.user == 'user'
         assert obj.host == 'domain.com'
@@ -886,7 +891,7 @@ def test_plugin_email_dict_variations():
         'user': 'apprise@example.com',
         'password': 'abd123',
         'host': 'example.com'}, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
 
 @mock.patch('smtplib.SMTP_SSL')
@@ -916,7 +921,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert 'user2@yahoo.com' in results['targets']
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert mock_smtp.call_count == 0
     assert mock_smtp_ssl.call_count == 0
@@ -964,7 +969,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert 'user2@yahoo.com' in results['targets']
     assert 'ssl' == results['secure_mode']
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert mock_smtp.call_count == 0
     assert mock_smtp_ssl.call_count == 0
@@ -1010,7 +1015,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@hotmail.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     assert obj.smtp_host == 'smtp-mail.outlook.com'
     # No entries in the reply_to
     assert not obj.reply_to
@@ -1036,7 +1041,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@outlook.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     assert obj.smtp_host == 'smtp.outlook.com'
     # No entries in the reply_to
     assert not obj.reply_to
@@ -1062,7 +1067,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@outlook.com.au')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     assert obj.smtp_host == 'smtp.outlook.com'
     # No entries in the reply_to
     assert not obj.reply_to
@@ -1090,7 +1095,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
         'mailtos://outlook.com?smtp=smtp.outlook.com'
         '&user=user@outlook.com&pass=app.pw')
     obj1 = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj1, NotifyEmail) is True
+    assert isinstance(obj1, NotifyEmail)
     assert obj1.smtp_host == 'smtp.outlook.com'
     assert obj1.user == 'user@outlook.com'
     assert obj1.password == 'app.pw'
@@ -1118,7 +1123,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         'mailtos://user:app.pw@outlook.com')
     obj2 = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj2, NotifyEmail) is True
+    assert isinstance(obj2, NotifyEmail)
     assert obj2.smtp_host == obj1.smtp_host
     assert obj2.user == obj1.user
     assert obj2.password == obj1.password
@@ -1146,7 +1151,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         'mailto://user:pass@comcast.net')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     assert obj.smtp_host == 'smtp.comcast.net'
     assert obj.user == 'user@comcast.net'
     assert obj.password == 'pass'
@@ -1174,7 +1179,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@live.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     # No entries in the reply_to
     assert not obj.reply_to
 
@@ -1199,7 +1204,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         'mailtos://user:pass123@hotmail.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     # No entries in the reply_to
     assert not obj.reply_to
 
@@ -1228,7 +1233,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
         "mailtos://abc:password@xyz.cn:465?"
         "smtp=smtp.exmail.qq.com&mode=ssl")
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     # Verify our over-rides are in place
     assert obj.smtp_host == 'smtp.exmail.qq.com'
@@ -1272,7 +1277,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
         "mailtos://abc:password@xyz.cn?"
         "smtp=smtp.exmail.qq.com&mode=ssl&port=465")
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     # Verify our over-rides are in place
     assert obj.smtp_host == 'smtp.exmail.qq.com'
@@ -1307,7 +1312,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         "mailtos://user:pass@example.com?reply=noreply@example.com")
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     # Verify our over-rides are in place
     assert obj.smtp_host == 'example.com'
     assert obj.from_addr[0] == obj.app_id
@@ -1342,7 +1347,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     results = NotifyEmail.parse_url(
         "mailtos://user:pass@example.com?reply=Chris<noreply@example.ca>")
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     # Verify our over-rides are in place
     assert obj.smtp_host == 'example.com'
     assert obj.from_addr[0] == obj.app_id
@@ -1390,7 +1395,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert 'hello@concordium-explorer.nl' in results['targets']
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert mock_smtp.call_count == 0
     assert mock_smtp_ssl.call_count == 0
@@ -1440,7 +1445,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert results['smtp_host'] == ''
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     # During instantiation, our variables get detected
     assert obj.smtp_host == 'smtp.fastmail.com'
     assert obj.from_addr == ['Apprise', 'username@customdomain.com']
@@ -1491,7 +1496,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert results['smtp_host'] == ''
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
     # During instantiation, our variables get detected
     assert obj.smtp_host == 'smtp.fastmail.com'
     assert obj.from_addr == ['Custom', 'username@customdomain.com']
@@ -1548,7 +1553,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert 'mail@mail-domain.com' in results['targets']
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     # Not that our from_address takes on 'admin@domain.subdomain.com'
     assert obj.from_addr == ['Apprise', 'admin@domain.subdomain.com']
@@ -1605,7 +1610,7 @@ def test_plugin_email_plus_in_toemail(mock_smtp, mock_smtp_ssl):
     assert 'Plus Support<test+notification@gmail.com>' in results['targets']
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert len(obj.targets) == 1
     assert ('Plus Support', 'test+notification@gmail.com') in obj.targets
@@ -1653,7 +1658,7 @@ def test_plugin_email_plus_in_toemail(mock_smtp, mock_smtp_ssl):
     assert 'test+notification@gmail.com' in results['targets']
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert len(obj.targets) == 1
     assert (False, 'test+notification@gmail.com') in obj.targets
@@ -1697,7 +1702,7 @@ def test_plugin_email_plus_in_toemail(mock_smtp, mock_smtp_ssl):
     assert 'test+notification@gmail.com' in results['targets']
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert len(obj.targets) == 1
     assert (False, 'test+notification@gmail.com') in obj.targets
@@ -1753,7 +1758,291 @@ def test_plugin_email_formatting_990(mock_smtp, mock_smtp_ssl):
     assert 'me@mydomain.com' in results['targets']
 
     obj = Apprise.instantiate(results, suppress_exceptions=False)
-    assert isinstance(obj, NotifyEmail) is True
+    assert isinstance(obj, NotifyEmail)
 
     assert len(obj.targets) == 1
     assert (False, 'me@mydomain.com') in obj.targets
+
+
+def test_plugin_email_variables_1087():
+    """
+    NotifyEmail() GitHub Issue 1087
+    https://github.com/caronc/apprise/issues/1087
+    Email variables reported not working correctly
+
+    """
+
+    # Valid Configuration
+    result, _ = ConfigBase.config_parse(cleandoc("""
+    #
+    # Test Email Parsing
+    #
+    urls:
+      - mailtos://alt.lan/:
+        - user: testuser@alt.lan
+          pass: xxxxXXXxxx
+          smtp: smtp.alt.lan
+          to: alteriks@alt.lan
+    """), asset=AppriseAsset())
+
+    assert isinstance(result, list)
+    assert len(result) == 1
+
+    email = result[0]
+    assert email.from_addr == ['Apprise', 'testuser@alt.lan']
+    assert email.user == 'testuser@alt.lan'
+    assert email.smtp_host == 'smtp.alt.lan'
+    assert email.targets == [(False, 'alteriks@alt.lan')]
+    assert email.password == 'xxxxXXXxxx'
+
+    # Valid Configuration
+    result, _ = ConfigBase.config_parse(cleandoc("""
+    #
+    # Test Email Parsing where qsd over-rides all
+    #
+    urls:
+      - mailtos://alt.lan/?pass=abcd&user=joe@alt.lan:
+        - user: testuser@alt.lan
+          pass: xxxxXXXxxx
+          smtp: smtp.alt.lan
+          to: alteriks@alt.lan
+    """), asset=AppriseAsset())
+
+    assert isinstance(result, list)
+    assert len(result) == 1
+
+    email = result[0]
+    assert email.from_addr == ['Apprise', 'joe@alt.lan']
+    assert email.user == 'joe@alt.lan'
+    assert email.smtp_host == 'smtp.alt.lan'
+    assert email.targets == [(False, 'alteriks@alt.lan')]
+    assert email.password == 'abcd'
+
+
+@mock.patch('smtplib.SMTP_SSL')
+@mock.patch('smtplib.SMTP')
+def test_plugin_host_detection_from_source_email(mock_smtp, mock_smtp_ssl):
+    """
+    NotifyEmail() Discord Issue reporting that the following did not work:
+     mailtos://?smtp=mobile.charter.net&pass=password&user=name@spectrum.net
+
+    """
+
+    response = mock.Mock()
+    mock_smtp_ssl.return_value = response
+    mock_smtp.return_value = response
+
+    results = NotifyEmail.parse_url(
+        'mailtos://spectrum.net?smtp=mobile.charter.net'
+        '&pass=password&user=name@spectrum.net')
+
+    assert isinstance(results, dict)
+    assert 'name@spectrum.net' == results['user']
+    assert 'spectrum.net' == results['host']
+    assert 'mobile.charter.net' == results['smtp_host']
+    assert 'password' == results['password']
+
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+
+    assert len(obj.targets) == 1
+    assert (False, 'name@spectrum.net') in obj.targets
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'name@spectrum.net'
+    assert obj.password == 'password'
+    assert obj.user == 'name@spectrum.net'
+    assert obj.secure is True
+    assert obj.port == 587
+    assert obj.smtp_host == 'mobile.charter.net'
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert obj.notify('body', 'title') is True
+
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+    # Store our Sent Arguments
+    # Syntax is:
+    #  sendmail(from_addr, to_addrs, msg, mail_options=(), rcpt_options=())
+    #             [0]        [1]     [2]
+    _from = response.sendmail.call_args[0][0]
+    _to = response.sendmail.call_args[0][1]
+    _msg = response.sendmail.call_args[0][2]
+    assert _from == 'name@spectrum.net'
+    assert isinstance(_to, list)
+    assert len(_to) == 1
+    assert _to[0] == 'name@spectrum.net'
+    assert _msg.split('\n')[-3] == 'body'
+
+    #
+    # Now let's do a shortened version of the same URL where the host isn't
+    # specified but is parseable from he user login
+    #
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
+    results = NotifyEmail.parse_url(
+        'mailtos://?smtp=mobile.charter.net'
+        '&pass=password&user=name@spectrum.net')
+
+    assert isinstance(results, dict)
+    assert 'name@spectrum.net' == results['user']
+    assert '' == results['host']  # No hostname defined; it's detected later
+    assert 'mobile.charter.net' == results['smtp_host']
+    assert 'password' == results['password']
+
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+
+    assert len(obj.targets) == 1
+    assert (False, 'name@spectrum.net') in obj.targets
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'name@spectrum.net'
+    assert obj.password == 'password'
+    assert obj.user == 'name@spectrum.net'
+    assert obj.secure is True
+    assert obj.port == 587
+    assert obj.smtp_host == 'mobile.charter.net'
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert obj.notify('body', 'title') is True
+
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+    # Store our Sent Arguments
+    # Syntax is:
+    #  sendmail(from_addr, to_addrs, msg, mail_options=(), rcpt_options=())
+    #             [0]        [1]     [2]
+    _from = response.sendmail.call_args[0][0]
+    _to = response.sendmail.call_args[0][1]
+    _msg = response.sendmail.call_args[0][2]
+    assert _from == 'name@spectrum.net'
+    assert isinstance(_to, list)
+    assert len(_to) == 1
+    assert _to[0] == 'name@spectrum.net'
+    assert _msg.split('\n')[-3] == 'body'
+
+    #
+    # Now let's do a shortened version of the same URL where the host isn't
+    # specified but is parseable from he user login
+    #
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
+    results = NotifyEmail.parse_url(
+        'mailtos://?smtp=mobile.charter.net'
+        '&pass=password&user=userid-without-domain')
+
+    assert isinstance(results, dict)
+    assert 'userid-without-domain' == results['user']
+    assert '' == results['host']  # No hostname defined
+    assert 'mobile.charter.net' == results['smtp_host']
+    assert 'password' == results['password']
+
+    with pytest.raises(TypeError):
+        # We will fail
+        Apprise.instantiate(results, suppress_exceptions=False)
+
+    #
+    # Now support target emails in place of the hostname
+    #
+
+    mock_smtp.reset_mock()
+    mock_smtp_ssl.reset_mock()
+    response.reset_mock()
+
+    results = NotifyEmail.parse_url(
+        'mailtos://John Doe<john%40yahoo.ca>?smtp=mobile.charter.net'
+        '&pass=password&user=name@spectrum.net')
+
+    assert isinstance(results, dict)
+    assert 'name@spectrum.net' == results['user']
+    assert '' == results['host']  # No hostname defined; it's detected later
+    assert 'mobile.charter.net' == results['smtp_host']
+    assert 'password' == results['password']
+
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, NotifyEmail) is True
+
+    assert len(obj.targets) == 1
+    assert ('John Doe', 'john@yahoo.ca') in obj.targets
+    assert obj.from_addr[0] == obj.app_id
+    assert obj.from_addr[1] == 'name@spectrum.net'
+    assert obj.password == 'password'
+    assert obj.user == 'name@spectrum.net'
+    assert obj.secure is True
+    assert obj.port == 587
+    assert obj.smtp_host == 'mobile.charter.net'
+
+    assert mock_smtp.call_count == 0
+    assert mock_smtp_ssl.call_count == 0
+    assert obj.notify('body', 'title') is True
+
+    assert mock_smtp.call_count == 1
+    assert mock_smtp_ssl.call_count == 0
+    assert response.starttls.call_count == 1
+    assert response.login.call_count == 1
+    assert response.sendmail.call_count == 1
+    # Store our Sent Arguments
+    # Syntax is:
+    #  sendmail(from_addr, to_addrs, msg, mail_options=(), rcpt_options=())
+    #             [0]        [1]     [2]
+    _from = response.sendmail.call_args[0][0]
+    _to = response.sendmail.call_args[0][1]
+    _msg = response.sendmail.call_args[0][2]
+    assert _from == 'name@spectrum.net'
+    assert isinstance(_to, list)
+    assert len(_to) == 1
+    assert _to[0] == 'john@yahoo.ca'
+    assert _msg.split('\n')[-3] == 'body'
+
+
+@mock.patch('smtplib.SMTP_SSL')
+@mock.patch('smtplib.SMTP')
+def test_plugin_email_by_ipaddr_1113(mock_smtp, mock_smtp_ssl):
+    """
+    NotifyEmail() GitHub Issue 1113
+    https://github.com/caronc/apprise/issues/1113
+    Email with ip addresses not working
+
+    """
+
+    response = mock.Mock()
+    mock_smtp_ssl.return_value = response
+    mock_smtp.return_value = response
+
+    results = NotifyEmail.parse_url(
+        'mailto://10.0.0.195:25/?to=alerts@example.com&'
+        'from=sender@example.com')
+
+    assert isinstance(results, dict)
+    assert results['user'] is None
+    assert results['password'] is None
+    assert results['host'] == '10.0.0.195'
+    assert results['from_addr'] == 'sender@example.com'
+    assert isinstance(results['targets'], list)
+    assert len(results['targets']) == 1
+    assert results['targets'][0] == 'alerts@example.com'
+    assert results['port'] == 25
+
+    email = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(email, NotifyEmail) is True
+
+    assert len(email.targets) == 1
+    assert (False, 'alerts@example.com') in email.targets
+
+    assert email.from_addr == (False, 'sender@example.com')
+    assert email.user is None
+    assert email.password is None
+    assert email.smtp_host == '10.0.0.195'
+    assert email.port == 25
+    assert email.targets == [(False, 'alerts@example.com')]
