@@ -40,15 +40,15 @@ import pytest
 import requests
 import json
 from apprise import Apprise
-from apprise.plugins.NotifyFCM import NotifyFCM
+from apprise.plugins.fcm import NotifyFCM
 from helpers import AppriseURLTester
 
 try:
-    from apprise.plugins.NotifyFCM.oauth import GoogleOAuth
-    from apprise.plugins.NotifyFCM.common import FCM_MODES
-    from apprise.plugins.NotifyFCM.priority import (
+    from apprise.plugins.fcm.oauth import GoogleOAuth
+    from apprise.plugins.fcm.common import FCM_MODES
+    from apprise.plugins.fcm.priority import (
         FCMPriorityManager, FCM_PRIORITIES)
-    from apprise.plugins.NotifyFCM.color import FCMColorManager
+    from apprise.plugins.fcm.color import FCMColorManager
     from cryptography.exceptions import UnsupportedAlgorithm
 
 except ImportError:
@@ -873,13 +873,13 @@ def test_plugin_fcm_color_manager():
 
     # We will be `true` because we can acquire a color based on what was
     # passed in
-    assert bool(instance) is True
+    assert bool(instance)
 
     # Custom color
     instance = FCMColorManager('#A2B3A4')
     assert isinstance(instance.get(), str)
     assert instance.get() == '#a2b3a4'
-    assert bool(instance) is True
+    assert bool(instance)
     # str() response does not include hashtag
     assert str(instance) == 'a2b3a4'
 
@@ -888,7 +888,7 @@ def test_plugin_fcm_color_manager():
     assert isinstance(instance.get(), str)
     # Hashtag is always part of output
     assert instance.get() == '#a2b3a4'
-    assert bool(instance) is True
+    assert bool(instance)
     # str() response does not include hashtag
     assert str(instance) == 'a2b3a4'
 
@@ -897,7 +897,7 @@ def test_plugin_fcm_color_manager():
     assert isinstance(instance.get(), str)
     # Hashtag is always part of output
     assert instance.get() == '#aacc44'
-    assert bool(instance) is True
+    assert bool(instance)
     # str() response does not include hashtag
     assert str(instance) == 'aacc44'
 
