@@ -33,7 +33,7 @@ import pytest
 from apprise import Apprise, AppriseAsset, AppriseAttachment, NotifyType
 from json import dumps
 
-from apprise.plugins.NotifyMatrix import NotifyMatrix
+from apprise.plugins.matrix import NotifyMatrix
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -254,27 +254,27 @@ def test_plugin_matrix_general(mock_post, mock_get, mock_put):
 
     # Variation Initializations
     obj = NotifyMatrix(host='host', targets='#abcd')
-    assert isinstance(obj, NotifyMatrix) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyMatrix)
+    assert isinstance(obj.url(), str)
     # Registration successful
     assert obj.send(body="test") is True
 
     obj = NotifyMatrix(host='host', user='user', targets='#abcd')
-    assert isinstance(obj, NotifyMatrix) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyMatrix)
+    assert isinstance(obj.url(), str)
     # Registration successful
     assert obj.send(body="test") is True
 
     obj = NotifyMatrix(host='host', password='passwd', targets='#abcd')
-    assert isinstance(obj, NotifyMatrix) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyMatrix)
+    assert isinstance(obj.url(), str)
     # A username gets automatically generated in these cases
     assert obj.send(body="test") is True
 
     obj = NotifyMatrix(
         host='host', user='user', password='passwd', targets='#abcd')
-    assert isinstance(obj.url(), str) is True
-    assert isinstance(obj, NotifyMatrix) is True
+    assert isinstance(obj.url(), str)
+    assert isinstance(obj, NotifyMatrix)
     # Registration Successful
     assert obj.send(body="test") is True
 
@@ -282,23 +282,23 @@ def test_plugin_matrix_general(mock_post, mock_get, mock_put):
     kwargs = NotifyMatrix.parse_url(
         'matrix://user:passwd@hostname/#abcd?format=html')
     obj = NotifyMatrix(**kwargs)
-    assert isinstance(obj.url(), str) is True
-    assert isinstance(obj, NotifyMatrix) is True
-    obj.send(body="test") is True
-    obj.send(title="title", body="test") is True
+    assert isinstance(obj.url(), str)
+    assert isinstance(obj, NotifyMatrix)
+    assert obj.send(body="test") is True
+    assert obj.send(title="title", body="test") is True
 
     kwargs = NotifyMatrix.parse_url(
         'matrix://user:passwd@hostname/#abcd/#abcd:localhost?format=markdown')
     obj = NotifyMatrix(**kwargs)
-    assert isinstance(obj.url(), str) is True
-    assert isinstance(obj, NotifyMatrix) is True
-    obj.send(body="test") is True
-    obj.send(title="title", body="test") is True
+    assert isinstance(obj.url(), str)
+    assert isinstance(obj, NotifyMatrix)
+    assert obj.send(body="test") is True
+    assert obj.send(title="title", body="test") is True
 
     kwargs = NotifyMatrix.parse_url(
         'matrix://user:passwd@hostname/#abcd/!abcd:localhost?format=text')
     obj = NotifyMatrix(**kwargs)
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
     assert isinstance(obj, NotifyMatrix) is True
     obj.send(body="test") is True
     obj.send(title="title", body="test") is True
@@ -309,8 +309,8 @@ def test_plugin_matrix_general(mock_post, mock_get, mock_put):
     obj = NotifyMatrix(**kwargs)
     assert isinstance(obj.url(), str) is True
     assert isinstance(obj, NotifyMatrix) is True
-    obj.send(body="test") is True
-    obj.send(title="title", body="test") is True
+    assert obj.send(body="test") is True
+    assert obj.send(title="title", body="test") is True
 
     with pytest.raises(TypeError):
         # invalid message type specified
