@@ -29,7 +29,7 @@
 import pytest
 import requests
 
-from apprise.plugins.NotifyMattermost import NotifyMattermost
+from apprise.plugins.mattermost import NotifyMattermost
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
