@@ -26,7 +26,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-from apprise.plugins.NotifyOneSignal import NotifyOneSignal
+from apprise.plugins.one_signal import NotifyOneSignal
 from helpers import AppriseURLTester
 from apprise import Apprise
 
