@@ -28,10 +28,11 @@
 
 from unittest import mock
 
+import pytest
 import requests
 from json import dumps
 from apprise import Apprise
-from apprise.plugins.NotifyTwist import NotifyTwist
+from apprise.plugins.twist import NotifyTwist
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -111,19 +112,11 @@ def test_plugin_twist_init():
     NotifyTwist() init()
 
     """
-    try:
+    with pytest.raises(TypeError):
         NotifyTwist(email='invalid', targets=None)
-        assert False
-    except TypeError:
-        # Invalid email address
-        assert True
 
-    try:
+    with pytest.raises(TypeError):
         NotifyTwist(email='user@domain', targets=None)
-        assert False
-    except TypeError:
-        # No password was specified
-        assert True
 
     # Simple object initialization
     result = NotifyTwist(
